# 참고자료

## 참고 웹사이트

- [DOOSAN ROBOTICS Youtube](https://www.youtube.com/@DOOSANROBOTICS)
- [Doosan Robot LAB](https://robotlab.doosanrobotics.com/ko/Index)
- [GitHub Education 설명서](https://docs.github.com/ko/education)

## 뉴스

- [두산로보틱스, GPT 기반 협동로봇 솔루션 개발 나선다](https://news.microsoft.com/ko-kr/2023/08/28/doosanrobotics/)
